aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Controller
diff options
context:
space:
mode:
authorLuke Pulverenti <luke.pulverenti@gmail.com>2014-01-23 13:46:33 -0500
committerLuke Pulverenti <luke.pulverenti@gmail.com>2014-01-23 13:46:33 -0500
commit36210922e58b6d1022c5d0ed38e3a1baf3ecf41b (patch)
treef17d6af43322d6e23cd36b6acfae33256e608b60 /MediaBrowser.Controller
parent145285784bfb6a2fcd0e9234d569d7ad5083516f (diff)
handle more duplicate episode paths when deleting
Diffstat (limited to 'MediaBrowser.Controller')
-rw-r--r--MediaBrowser.Controller/LiveTv/LiveTvServiceStatusInfo.cs12
1 files changed, 9 insertions, 3 deletions
diff --git a/MediaBrowser.Controller/LiveTv/LiveTvServiceStatusInfo.cs b/MediaBrowser.Controller/LiveTv/LiveTvServiceStatusInfo.cs
index 4159e5271b..da6b8ab17a 100644
--- a/MediaBrowser.Controller/LiveTv/LiveTvServiceStatusInfo.cs
+++ b/MediaBrowser.Controller/LiveTv/LiveTvServiceStatusInfo.cs
@@ -74,12 +74,18 @@ namespace MediaBrowser.Controller.LiveTv
public string ChannelId { get; set; }
/// <summary>
/// Gets or sets the timer identifier.
/// </summary>
- /// <value>The timer identifier.</value>
- public string TimerId { get; set; }
+ /// <value>The recording identifier.</value>
+ public string RecordingId { get; set; }
/// <summary>
+ /// Gets or sets the name of the program.
+ /// </summary>
+ /// <value>The name of the program.</value>
+ public string ProgramName { get; set; }
+
+ /// <summary>
/// Gets or sets the clients.
/// </summary>
/// <value>The clients.</value>
@@ -74,12 +74,18 @@ namespace MediaBrowser.Controller.LiveTv
public string ChannelId { get; set; }
/// <summary>
- /// Gets or sets the timer identifier.
+ /// Gets or sets the recording identifier.
/// </summary>